==> entidades-1.0.4.tgz: package/test/productos.js <==
var expect = require('chai').expect
var should = require('chai').should()
var productos = require('../src/models/productos')
var babel = require('babel-core/register')


before(function (done) {
    console.log("  PRODUCTOS")
    console.log("  -----------")
    console.log("")
    console.log("  Al comenzar borra todos los productos\n")
    productos.deleteAll()
    done()
})

describe.skip('Funcionamiento de ABM de los productos', function () {
    it('al comenzar la base de datos debería estar en blanco', function (done) {
        productos.getProductos()
            .then(function (data) {
                expect(JSON.stringify(data)).to.equal("[]")
                done();
            })
            .catch(function (err) {
                done(err)
            })
    })
    it('debería crear un producto', function () {
        var p = {
            idProducto: "123456"
        }
        productos.addProducto(p)
    })
    it('deberia obtener el producto creado', function () {
        var result = productos.getProducto("123456")
        return result.then(function (data) {
            expect(JSON.stringify(data)).to.equal(JSON.stringify({
                "idProducto": "123456"
            }))
        })
    })
    it.skip('no debería duplicar un producto', function (done) {
        var p = {
            idProducto: "123456"
        }
        var result = productos.addProducto(p)
        done(result)
    })
    it.skip('debería borrar el producto creado', () => {
        productos.deleteProducto("123456");
    })
    it.skip('en este momento la tabla de productos debería estar en blanco', function () {
        var result = productos.getProducto("123456").then(function (data) {
            expect(data).to.equal({})
        })
    })
})

==> entidades-1.0.7.tgz: package/test/productos.js <==
var expect = require('chai').expect
var should = require('chai').should()
var productos = require('../src/models/productos')
var babel = require('babel-core/register')


before(function (done) {
    console.log("  PRODUCTOS")
    console.log("  -----------")
    console.log("")
    console.log("  Al comenzar borra todos los productos\n")
    //productos.deleteAll()
    done()
})

describe.skip('Funcionamiento de ABM de los productos', function () {
    it('configura los indices en la base', function (){
        productos.initializeProductos()
    })
    it.skip('al comenzar la base de datos debería estar en blanco', function (done) {
        productos.getProductos()
            .then(function (data) {
                expect(JSON.stringify(data)).to.equal("[]")
                done();
            })
            .catch(function (err) {
                done(err)
            })
    })
    it('debería crear un producto', function () {
        var p = {
            idProducto: "123456"
        }
        productos.addProducto(p)
    })
    it('deberia obtener el producto creado', function () {
        var result = productos.getProducto("123456")
        return result.then(function (data) {
            expect(JSON.stringify(data)).to.equal(JSON.stringify({
                "idProducto": "123456"
            }))
        })
    })
    it.skip('no debería duplicar un producto', function (done) {
        var p = {
            idProducto: "123456"
        }
        var result = productos.addProducto(p)
        done(result)
    })
    it.skip('debería borrar el producto creado', () => {
        productos.deleteProducto("123456");
    })
    it.skip('en este momento la tabla de productos debería estar en blanco', function () {
        var result = productos.getProducto("123456").then(function (data) {
            expect(data).to.equal({})
        })
    })
})
